# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-20 13:13
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DummyRecipient',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('email_address', models.EmailField(max_length=254)),
                ('name', models.CharField(max_length=50)),
            ],
        ),
        migrations.CreateModel(
            name='Email',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('subject', models.CharField(blank=True, max_length=255)),
                ('payload', models.TextField(blank=True)),
                ('plaintext_message', models.TextField(blank=True)),
                ('html_message', models.TextField(blank=True, null=True)),
                ('from_email', models.EmailField(max_length=254)),
                ('is_forwarded', models.BooleanField(default=False)),
                ('backend', models.CharField(blank=True, max_length=32, null=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'ordering': ['subject', 'created'],
            },
        ),
        migrations.CreateModel(
            name='Recipient',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('email', models.EmailField(max_length=254, unique=True)),
            ],
        ),
        migrations.AddField(
            model_name='email',
            name='recipients',
            field=models.ManyToManyField(related_name='emails', to='mailtrail.Recipient'),
        ),
    ]
